@@ -64,7 +64,8 @@ ODi_Style_Style::ODi_Style_Style(ODi_ElementStack& rElementStack) :
  */
 void ODi_Style_Style::startElement(const gchar* pName,
                                   const gchar** ppAtts,
-                                  ODi_ListenerStateAction& rAction) {
+								   ODi_ListenerStateAction& /*rAction*/) 
+{
 
     if (!strcmp("style:style", pName)) {
         
@@ -410,6 +411,10 @@ void ODi_Style_Style::_parse_style_textProperties(const gchar** ppProps) {
     }
     
     pVal = UT_getAttribute("style:font-name", ppProps);
+    if(!pVal) {
+      pVal = UT_getAttribute("fo:font-family", ppProps);
+    }
+
     if(pVal) {
         m_fontName.assign(pVal);
     }
