@@ -1335,14 +1335,14 @@ void s_XSL_FO_Listener::_handlePageSize(PT_AttrPropIndex api)
 		UT_Dimension docUnit = m_pDocument->m_docPageSize.getDims(); 
 		UT_UTF8String buf;
 
+		// page-width, page-height
 		UT_UTF8String_sprintf(buf, " page-width=\"%f%s\"", m_pDocument->m_docPageSize.Width(docUnit), UT_dimensionName(docUnit));
 		master += buf;
 		buf.clear();
 
-		UT_UTF8String_sprintf(" page-height=\"%f%s\"", m_pDocument->m_docPageSize.Height(docUnit), UT_dimensionName(docUnit));
+		UT_UTF8String_sprintf(buf, " page-height=\"%f%s\"", m_pDocument->m_docPageSize.Height(docUnit), UT_dimensionName(docUnit));
 		master += buf;
 	}
-	// page-width, page-height
 
 	master += " master-name=\"first\"";
 
@@ -1422,10 +1422,12 @@ void s_XSL_FO_Listener::_openSection(PT_AttrPropIndex api)
 }
 
 #define PROPERTY(x) \
-	if (pAP->getProperty(x, szValue)) \
+	if (pAP->getProperty(x, szValue) && szValue && *szValue) \
 	{ \
+		UT_UTF8String esc = szValue; \
+		esc.escapeXML(); \
 		buf += " "x"=\""; \
-		buf += szValue; \
+		buf += esc.utf8_str(); \
 		buf += "\""; \
 	}
 
